---
page_title: "keycloak_authentication_flow Resource"
---

# keycloak\_authentication\_flow Resource

Allows for creating and managing an authentication flow within Keycloak.

[Authentication flows](https://www.keycloak.org/docs/11.0/server_admin/index.html#_authentication-flows) describe a sequence
of actions that a user or service must perform in order to be authenticated to Keycloak. The authentication flow itself
is a container for these actions, which are otherwise known as executions.

## Example Usage

```hcl
resource "keycloak_realm" "realm" {
  realm   = "my-realm"
  enabled = true
}

resource "keycloak_authentication_flow" "flow" {
  realm_id = keycloak_realm.realm.id
  alias    = "my-flow-alias"
}

resource "keycloak_authentication_execution" "execution" {
  realm_id          = keycloak_realm.realm.id
  parent_flow_alias = keycloak_authentication_flow.flow.alias
  authenticator     = "identity-provider-redirector"
  requirement       = "REQUIRED"
}
```

## Argument Reference

- `realm_id` - (Required) The realm that the authentication flow exists in.
- `alias` - (Required) The alias for this authentication flow.
- `description` - (Optional) A description for the authentication flow.
- `provider_id` - (Optional) The type of authentication flow to create. Valid choices include `basic-flow` and `client-flow`. Defaults to `basic-flow`.

## Import

Authentication flows can be imported using the format `{{realmId}}/{{authenticationFlowId}}`. The authentication flow ID is
typically a GUID which is autogenerated when the flow is created via Keycloak.

Unfortunately, it is not trivial to retrieve the authentication flow ID from the UI. The best way to do this is to visit the
"Authentication" page in Keycloak, and use the network tab of your browser to view the response of the API call to `/auth/admin/realms/${realm}/authentication/flows`,
which will be a list of authentication flows.

Example:

```bash
$ terraform import keycloak_authentication_flow.flow my-realm/e9a5641e-778c-4daf-89c0-f4ef617987d1
```
