---
page_title: "keycloak_authentication_subflow Resource"
---

# keycloak\_authentication\_subflow Resource

Allows for creating and managing an authentication subflow within Keycloak.

Like authentication flows, authentication subflows are containers for authentication executions.
As its name implies, an authentication subflow is contained in an authentication flow.

## Example Usage

```hcl
resource "keycloak_realm" "realm" {
  realm   = "my-realm"
  enabled = true
}

resource "keycloak_authentication_flow" "flow" {
  realm_id = keycloak_realm.realm.id
  alias    = "my-flow-alias"
}

resource "keycloak_authentication_subflow" "subflow" {
  realm_id          = keycloak_realm.realm.id
  alias             = "my-subflow-alias"
  parent_flow_alias = keycloak_authentication_flow.flow.alias
  provider_id       = "basic-flow"
  requirement       = "ALTERNATIVE"
}
```

## Argument Reference

- `realm_id` - (Required) The realm that the authentication subflow exists in.
- `alias` - (Required) The alias for this authentication subflow.
- `parent_flow_alias` - (Required) The alias for the parent authentication flow.
- `provider_id` - (Optional) The type of authentication subflow to create. Valid choices include `basic-flow`, `form-flow`
and `client-flow`. Defaults to `basic-flow`.
- `description` - (Optional) A description for the authentication subflow.
- `authenticator` - (Optional) The name of the authenticator. Might be needed to be set with certain custom subflows with specific
authenticators. In general this will remain empty.
- `requirement`- (Optional) The requirement setting, which can be one of `REQUIRED`, `ALTERNATIVE`, `OPTIONAL`, `CONDITIONAL`,
or `DISABLED`. Defaults to `DISABLED`.

## Import

Authentication flows can be imported using the format `{{realmId}}/{{parentFlowAlias}}/{{authenticationSubflowId}}`.
The authentication subflow ID is typically a GUID which is autogenerated when the subflow is created via Keycloak.

Unfortunately, it is not trivial to retrieve the authentication subflow ID from the UI. The best way to do this is to visit the
"Authentication" page in Keycloak, and use the network tab of your browser to view the response of the API call to
`/auth/admin/realms/${realm}/authentication/flows/{flow}/executions`, which will be a list of executions, where the subflow will be.
__The subflow ID is contained in the `flowID` field__ (not, as one could guess, the `id` field).

Example:

```bash
$ terraform import keycloak_authentication_subflow.subflow my-realm/"Parent Flow"/3bad1172-bb5c-4a77-9615-c2606eb03081
```
